netapp_ontap.resources.security_audit_log API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.security_audit_log`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

These APIs return audit log records. The GET requests retrieves all audit log records. An audit log record contains information such as timestamp, node name, index and so on.

## Example

### Retrieving audit log records

The following example shows the audit log records.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SecurityAuditLog

    with HostConnection(
        "<cluster-ip>", username="admin", password="password", verify=False
    ):
        print(list(SecurityAuditLog.get_collection()))

Try it out

    [
        SecurityAuditLog(
            {
                "index": 4294967299,
                "user": "admin",
                "location": "172.21.16.89",
                "node": {
                    "uuid": "bc9af9da-41bb-11e9-a3db-005056bb27cf",
                    "name": "node1",
                    "_links": {
                        "self": {
                            "href": "/api/cluster/nodes/bc9af9da-41bb-11e9-a3db-005056bb27cf"
                        }
                    },
                },
                "state": "pending",
                "scope": "cluster",
                "timestamp": "2019-03-08T11:03:32-05:00",
                "application": "http",
                "input": "GET /api/security/audit/destinations/",
            }
        )
    ]

## Classes

`class SecurityAuditLog (*args, **kwargs)`

  Allows interaction with SecurityAuditLog objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves the administrative audit log viewer.

    ### Learn more

    - `DOC /security/audit/messages`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves the administrative audit log viewer.

    ### Learn more

    - `DOC /security/audit/messages`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves the administrative audit log viewer.

    ### Learn more

    - `DOC /security/audit/messages`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class SecurityAuditLogSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SecurityAuditLog object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `application GET`

    This identifies the "application" by which the request was processed.

    Valid choices:

    - internal
    - console
    - rsh
    - telnet
    - ssh
    - ontapi
    - http
    - system
  `command_id GET`

    This is the command ID for this request. Each command received on a CLI session is assigned a command ID. This enables you to correlate a request and response.

  `index GET`

    Internal index for accessing records with same time/node. This is a 64 bit unsigned value.

  `input GET`

    The request.

  `links GET`

    The links field of the security_audit_log.

  `location GET`

    This identifies the location of the remote user. This is an IP address or "console".

  `message GET`

    This is an optional field that might contain "error" or "additional information" about the status of a command.

  `node GET POST PATCH`

    The node field of the security_audit_log.

  `scope GET POST PATCH`

    Set to "svm" when the request is on a data SVM; otherwise set to "cluster".

    Valid choices:

    - svm
    - cluster
  `session_id GET`

    This is the session ID on which the request is received. Each SSH session is assigned a session ID. Each http/ontapi/snmp request is assigned a unique session ID.

  `state GET`

    State of of this request.

    Valid choices:

    - pending
    - success
    - error
  `svm GET POST PATCH`

    The svm field of the security_audit_log.

  `timestamp GET`

    Log entry timestamp. Valid in URL

  `user GET`

    Username of the remote user.